@@ -114,6 +114,7 @@ public:
 
     Q_INVOKABLE QString currentLinkUrl() const;
     Q_INVOKABLE QString currentLinkText() const;
+    Q_INVOKABLE [[nodiscard]] QString anchorAt(const QPointF &p) const;
     Q_INVOKABLE void updateLink(const QString &linkUrl, const QString &linkText);
     Q_INVOKABLE void insertImage(const QUrl &imagePath);
     Q_INVOKABLE void insertTable(int rows, int columns);
@@ -211,6 +212,16 @@ private:
     NestedListHelper m_nestedListHelper;
     QString m_frontMatter;
     QString m_activeLink;
+
+    // Cache data to dismiss redundant UI calls.
+    QString m_lastFontFamily;
+    Qt::Alignment m_lastAlignment;
+    bool m_lastBold;
+    bool m_lastItalic;
+    bool m_lastUnderline;
+    bool m_lastStrikethrough;
+    int m_lastFontSize;
+    QColor m_lastTextColor;
 };
 
 #endif // DOCUMENTHANDLER_H
