@@ -4,7 +4,10 @@
 */
 
 #include <KAboutData>
+#if __has_include("KCrash")
 #include <KCrash>
+#endif
+#include <KIconTheme>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <QApplication>
@@ -18,7 +21,11 @@
 #include "../marknote-version.h"
 #include "colorschemer.h"
 #include "config.h"
-#include "windowcontroller.h"
+#include "sketchhistory.h"
+
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
 
 #ifdef Q_OS_WINDOWS
 #include <Windows.h>
@@ -32,10 +39,7 @@ using namespace Qt::Literals::StringLiterals;
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
-
+    KIconTheme::initTheme();
     QIcon::setFallbackThemeName(u"breeze"_s);
     QApplication app(argc, argv);
     // Default to org.kde.desktop style unless the user forces another style
@@ -43,12 +47,6 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-    KCrash::initialize();
-
-#ifdef WITH_BREEZEICONS_LIB
-    BreezeIcons::initIcons();
-#endif
-
 #ifdef Q_OS_WINDOWS
     if (AttachConsole(ATTACH_PARENT_PROCESS)) {
         freopen("CONOUT$", "w", stdout);
@@ -74,7 +72,7 @@ int main(int argc, char *argv[])
                      QStringLiteral(MARKNOTE_VERSION_STRING),
                      i18n("Note taking application"),
                      KAboutLicense::GPL_V2,
-                     i18n("© 2023 Mathis Brüchert"));
+                     i18n("© 2023-2026 Mathis Brüchert"));
     about.addAuthor(i18n("Mathis Brüchert"),
                     i18n("Maintainer"),
                     QStringLiteral("mbb@kaidan.im"),
@@ -88,10 +86,13 @@ int main(int argc, char *argv[])
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
     KAboutData::setApplicationData(about);
+#if __has_include("KCrash")
+    KCrash::initialize();
+#endif
 
     ColorSchemer colorScheme;
-    if (!MarknoteSettings::self()->colorScheme().isEmpty()) {
-        colorScheme.apply(MarknoteSettings::self()->colorScheme());
+    if (!Config::self()->colorScheme().isEmpty()) {
+        colorScheme.apply(Config::self()->colorScheme());
     }
 
     QCommandLineParser parser;
@@ -100,7 +101,7 @@ int main(int argc, char *argv[])
     about.processCommandLine(&parser);
 
     QQmlApplicationEngine engine;
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+    KLocalization::setupLocalizedContext(&engine);
 
     if (parser.positionalArguments().length() > 0) {
         const auto path = parser.positionalArguments()[0];
@@ -117,26 +118,11 @@ int main(int argc, char *argv[])
         return -1;
     }
 
+    qRegisterMetaType<Stroke>("Stroke");
+
     QObject::connect(QApplication::instance(), &QCoreApplication::aboutToQuit, QApplication::instance(), [] {
-        MarknoteSettings::self()->save();
+        Config::self()->save();
     });
 
-    QQuickWindow *window = nullptr;
-
-    const auto rootObjects = engine.rootObjects();
-    for (auto obj : rootObjects) {
-        auto view = qobject_cast<QQuickWindow *>(obj);
-        if (view) {
-            window = view;
-            break;
-        }
-    }
-
-    if (window != nullptr) {
-        auto controller = engine.singletonInstance<WindowController *>(QStringLiteral("org.kde.marknote"), QStringLiteral("WindowController"));
-        controller->setWindow(window);
-        controller->restoreGeometry();
-    }
-
     return app.exec();
 }
